"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.jwtFromCompact = void 0;
const base64url_1 = require("../base64url");
const error_1 = require("./error");
const jwtFromCompact = (compact) => {
    if (compact.includes('~')) {
        throw new error_1.JwtError('compact JWT includes `~` which is only allowed in an sd-jwt. Please use sdJwtFromCompact() instead.');
    }
    if ((compact.match(/\./g) || []).length !== 2) {
        throw new error_1.JwtError('compact JWT must include two periods (.)');
    }
    const [compactHeader, compactPayload, encodedSignature] = compact.split('.');
    if (!encodedSignature || encodedSignature.length === 0) {
        throw new error_1.JwtError('A signature must be provided within the context of sd-jwt');
    }
    const header = base64url_1.Base64url.decodeToJson(compactHeader);
    const payload = base64url_1.Base64url.decodeToJson(compactPayload);
    const signature = base64url_1.Base64url.decode(encodedSignature);
    return {
        header,
        payload,
        signature
    };
};
exports.jwtFromCompact = jwtFromCompact;
//# sourceMappingURL=compact.js.map