"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var _Disclosure_digest;
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDisclosureWithDigest = exports.Disclosure = void 0;
const decode_1 = require("@sd-jwt/decode");
const utils_1 = require("@sd-jwt/utils");
const error_1 = require("./error");
class Disclosure {
    constructor(salt, value, key) {
        _Disclosure_digest.set(this, void 0);
        if (typeof value === 'number' && isNaN(value)) {
            throw new error_1.SdJwtError('NaN is not allowed to be used in a disclosure.');
        }
        if (typeof value === 'number' && !isFinite(value)) {
            throw new error_1.SdJwtError('Infinite is not allowed to be used in a disclosure.');
        }
        this.salt = salt;
        this.key = key;
        this.value = value;
    }
    static fromString(s) {
        const item = utils_1.Base64url.decodeToJson(s);
        return Disclosure.fromArray(item);
    }
    static fromArray(item) {
        return item[2] === undefined
            ? new Disclosure(item[0], item[1])
            : new Disclosure(item[0], item[2], item[1]);
    }
    get encoded() {
        return utils_1.Base64url.encodeFromJson(this.decoded);
    }
    get decoded() {
        return this.key
            ? [this.salt, this.key, this.value]
            : [this.salt, this.value];
    }
    get digest() {
        return __classPrivateFieldGet(this, _Disclosure_digest, "f");
    }
    /**
     * Set the digest of the disclosure.
     *
     * NOTE: this method statically sets the digest, and does not verify whether the digest is correct.
     * If you want to calculate the digest, use the `withCalculateDigest` method instead.
     */
    withDigest(digest) {
        __classPrivateFieldSet(this, _Disclosure_digest, digest, "f");
        return this;
    }
    withCalculateDigest(hasherAndAlgorithm, 
    // Whether to recalculate the digest, even if it is already set
    { recalculate = false } = {}) {
        // NOTE: the implementation of this method seems overly complex, but it allows
        // us to return a promise if the hasher returns a promise, and a value otherwise.
        // This allows this method to be used in environments where the calling scope
        // is not async, as long as the hasher is not async either.
        if (!recalculate && isDisclosureWithDigest(this)) {
            return this;
        }
        const digestResult = (0, decode_1.disclosureCalculateDigest)(this.asJson(), 
        // TODO: string vs HasherAlgorithm
        hasherAndAlgorithm.algorithm, hasherAndAlgorithm.hasher);
        if ((0, utils_1.isPromise)(digestResult)) {
            return digestResult.then((digest) => {
                __classPrivateFieldSet(this, _Disclosure_digest, digest, "f");
                // We know for sure that digest is defined now
                return this;
            });
        }
        else {
            __classPrivateFieldSet(this, _Disclosure_digest, digestResult, "f");
            // We know for sure that digest is defined now
            return this;
        }
    }
    toString() {
        return this.encoded;
    }
    asJson() {
        return {
            encoded: this.encoded,
            salt: this.salt,
            value: this.value,
            key: this.key,
            digest: this.digest
        };
    }
    static fromJson(disclosureJson) {
        const disclosure = new Disclosure(disclosureJson.salt, disclosureJson.value, disclosureJson.key);
        if ('digest' in disclosureJson) {
            disclosure.withDigest(disclosureJson.digest);
        }
        return disclosure;
    }
}
exports.Disclosure = Disclosure;
_Disclosure_digest = new WeakMap();
function isDisclosureWithDigest(disclosure) {
    return disclosure.digest !== undefined;
}
exports.isDisclosureWithDigest = isDisclosureWithDigest;
//# sourceMappingURL=disclosures.js.map