"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isPromise = exports.isObject = exports.hasByPath = exports.getByPath = exports.deleteByPath = exports.simpleDeepEqual = exports.getValueByKeyAnyLevel = exports.getAllKeys = void 0;
const sdJwt_1 = require("../sdJwt");
const getAllKeys = (object, keys = []) => {
    if (typeof object !== 'object' || typeof object === null)
        return keys;
    const record = object;
    const objectKeys = Object.keys(record);
    const objectValues = Object.values(record);
    keys.push(...objectKeys);
    for (const objectValue of objectValues) {
        if (typeof objectValue === 'object' &&
            objectValue !== null &&
            !Array.isArray(objectValue)) {
            (0, exports.getAllKeys)(objectValue, keys);
        }
    }
    return keys;
};
exports.getAllKeys = getAllKeys;
const getValueByKeyAnyLevel = (obj, key) => {
    // Check if the current object has the key
    if (obj && obj.hasOwnProperty(key)) {
        return obj[key];
    }
    // If not found in the current object, iterate over its properties
    for (const prop in obj) {
        if (obj.hasOwnProperty(prop) && typeof obj[prop] === 'object') {
            const result = (0, exports.getValueByKeyAnyLevel)(obj[prop], key);
            if (result !== undefined) {
                return result;
            }
        }
    }
};
exports.getValueByKeyAnyLevel = getValueByKeyAnyLevel;
const simpleDeepEqual = (lhs, rhs) => {
    if (lhs === rhs)
        return true;
    if (typeof lhs !== 'object' || typeof rhs !== 'object')
        return false;
    const l = Object.assign({}, lhs);
    const r = Object.assign({}, rhs);
    Object.keys(l).forEach((key) => l[key] === undefined && delete l[key]);
    Object.keys(r).forEach((key) => r[key] === undefined && delete r[key]);
    const keys1 = Object.keys(l);
    const keys2 = Object.keys(r);
    if (keys1.length !== keys2.length)
        return false;
    return keys1.every((key) => (0, exports.simpleDeepEqual)(l[key], r[key]));
};
exports.simpleDeepEqual = simpleDeepEqual;
const deleteByPath = (object, path) => {
    let currentObject = object;
    const parts = [...path];
    const last = parts.pop();
    for (const part of parts) {
        currentObject = currentObject[part];
        if (!currentObject) {
            return;
        }
    }
    if (last) {
        delete currentObject[last];
    }
};
exports.deleteByPath = deleteByPath;
const getByPath = (item, path) => {
    let current = item;
    for (const key of path) {
        if (Array.isArray(current)) {
            const keyAsNumber = Number(key);
            if (isNaN(keyAsNumber)) {
                throw new sdJwt_1.SdJwtError(`Unable to get ${path.join('.')} from array ${item}. ${key} is not a number.`);
            }
            if (keyAsNumber >= current.length) {
                throw new sdJwt_1.SdJwtError(`Unable to get ${path.join('.')} from array ${item}. ${key} is out of bounds.`);
            }
            current = current[keyAsNumber];
        }
        else if (typeof current === 'object' && current !== null) {
            if (!(key in current)) {
                throw new sdJwt_1.SdJwtError(`Unable to get ${path.join('.')} from ${item}. ${key} does not exists in ${current}.`);
            }
            current = current[key];
        }
        else {
            throw new sdJwt_1.SdJwtError(`Unable to get ${path.join('.')} from ${item}. ${key} is not an object or array.`);
        }
    }
    return current;
};
exports.getByPath = getByPath;
const hasByPath = (item, path) => {
    try {
        (0, exports.getByPath)(item, path);
        return true;
    }
    catch (_a) {
        return false;
    }
};
exports.hasByPath = hasByPath;
function isObject(input) {
    return typeof input === 'object' && input !== null && !Array.isArray(input);
}
exports.isObject = isObject;
function isPromise(value) {
    return (value instanceof Promise ||
        (value &&
            typeof value === 'object' &&
            value !== null &&
            'then' in value &&
            value.then === 'function'));
}
exports.isPromise = isPromise;
//# sourceMappingURL=utils.js.map